;==========================================================
; PUTBACK.LSP 
; Copyright 1995 by Looking Glass Microproducts
;==========================================================
; Restore R13 toolbar placement and visibility to that
; that defined in the .MNS file
;==========================================================
(Defun c:putback (/ error old_error fh notrans trim 
                    putback_main update_acadini)
   ;=======================================================
   ; Error Handler
   ;=======================================================
   (Defun error (s)
      (If (Not
             (Member
                S
                '("Function cancelled" "console break")
             )
          )
         (Alert s)
      )
      (While (/= 0 (GetVar "cmdactive"))
         (Command)
      )
      (Command "_.undo" "_end")
      (If fh (Progn (Close fh) (Setq fh Nil)))
      (Setq *Error* old_error)
      (Princ)
   )
   ;=======================================================
   ; Disallow transparent invocation of routine.
   ;=======================================================
   (Defun notrans ()
      (Cond
         ((Zerop (GetVar "cmdactive")))
         ((Alert
             "\nThis command may not be invoked transparently."
          )
         )
      )
   )
   ;=======================================================
   ; Trim Leading and Trailing Spaces from String
   ;=======================================================
   (Defun trim (astring)
      (While (WCmatch astring " *")
         (Setq astring (Substr astring 2))
      )
      (While (WCmatch astring "* ")
         (Setq
            astring (Substr astring 1 (1- (Strlen astring)))
         )
      )
      astring
   )
   ;======================================================
   ; Update ACAD.INI by removing the [Toolbars] section
   ;======================================================
   (Defun update_acadini (/ retval filename acadcfgw temp acadini
                          toolbars line lines)
      (Cond
         ((Null
             (Setq
                acadcfgw (Cond
                            ((Setq temp (GetEnv "acadcfgw"))
                               (Strcase (Strcat temp "\\"))
                            )
                            ("")
                         )
                acadini  (Strcat acadcfgw "ACAD.INI")
                filename (FindFile acadini)
             )
          )
            (Alert
               (Strcat "Cannot find file: " acadini)
            )
         )
         ((Null (Setq fh (Open filename "r")))
            (Alert
               (Strcat "Cannot read file: " filename)
            )
         )
         ((Progn
             (Princ
                (Strcat
                   "\nRemoving [Toolbars] from "
                   filename
                   "..."
                )
             )
             (While (Setq line (Read-Line fh))
                (Setq line (trim line))
                (If (WCmatch line "`[*`]")
                   (Setq
                      toolbars (= (Strcase line) "[TOOLBARS]")
                   )
                )
                (If (Not toolbars)
                   (Setq lines (Cons line lines))
                )
             )
             (Close fh)
             (Setq fh Nil)
             (Setq lines (Reverse lines))
             (Null (Setq fh (Open filename "w")))
          )
            (Alert
               (Strcat "Cannot write file: " filename)
            )
         )
         (T
            (MapCar
               '(Lambda
                  (line)
                  (Princ (Strcat line "\n") fh)
               )
               lines
            )
            (Close fh)
            (Setq fh Nil)
            (Setq retval T)
         )
      )
      retval
   )
   ;======================================================
   ; Putback Main
   ;======================================================
   (Defun putback_main (/ menuname)
      (Cond
         ((wcmatch (getvar "acadver") "~13*")
           (alert "This command requires AutoCAD R13")
         )
         ((wcmatch (getvar "platform") "~*Windows*")
           (alert "This command requires AutoCAD R13 for Windows")
         )
         ((=
             ""
             (Setq menuname (GetVar "menuname"))
          )
            (Alert "     No Menu Loaded.")
         )
         ((Null (update_acadini)))
         (T
            (Command "_.menu" "")
         )
      )
   )
   ;=======================================================
   ; Start of C:PUTBACK
   ;=======================================================
   (If (notrans)
      (Progn
         (Setq old_error *Error* *Error* error)
         (Setvar "cmdecho" 0)
         (Command "_.undo" "_group")
         (putback_main)
         (Command "_.undo" "_end")
         (Setq *Error* old_error)
      )
   )
   (Princ)
)
(Princ
   (Strcat
      "\nPUTBACK.LSP -- (c) 1995 "
      "by Looking Glass Microproducts"
   )
)
(Princ)
