; TIP1190.LSP: ZIGZAG.LSP   Folding Doors   (c)1996, Bill Bratt

;  ZIGZAG.LSP draws a parametric folding wall.
;  If you desire a single line zigzag line enter 0 for the panel 
;  thickness.
;  Bill Bratt

(setq PWIDTH 48.0) ;Initial default global variables.
(setq PTHICK 3.0)  ;Adjust as desired.

(defun C:ZIGZAG (/ S_CMD S_BLIP S_ORTH S_OSM SP EP ANGR ANGL L TEMP HALF 
    A A2 HAL AA2 AA QTR Q2 Q NUM PW DIFF HDIST H1 H2 H3 H4 
  PT1 PT2 PT3 PT4 PT5 PT6 PT7 LOOP)
  (START)
  (if (null (tblsearch "LAYER" "A-ZIGZAG"))
    (command "layer" "M" "A-ZIGZAG" "c" "2" "" "")
    (command "layer" "S" "A-ZIGZAG" "")
  )
  (setvar "osmode" 1)     ; endpt
  (prompt "\n\n\n**************** OSNAP is set for ENDpoint ***************")
  (setq SP (getpoint "\nPick Starting point: "))
  (prompt "\n\n\n**************** OSNAP is set for ENDpoint ***************")
  (setq EP (getpoint SP "\nPick Ending point: "))
  (setvar "osmode" 0)   ; none
  (setq ANGR (angle SP EP))
  (setq ANGL (angle EP SP))
  (setq L (distance SP EP))
  (princ "\nPick or Enter Panel Width <") 
  (princ PWIDTH) (princ ">: ")
  (setq TEMP (getdist))
  (if (= TEMP nil)  
    (setq TEMP PWIDTH)               
    (setq PWIDTH TEMP)
  )
  (princ "\nPick or Enter Panel Thickness <") 
  (princ PTHICK) (princ ">: ")
  (setq TEMP (getdist))
  (if (= TEMP nil)  
    (setq TEMP PTHICK)               
    (setq PTHICK TEMP)
  )
  (setq HALF (/ PWIDTH 2.0))
  (setq A2 (/ (* HALF HALF) 2.0))
  (setq A (sqrt A2))
  (setq HAL (/ PTHICK 2.0))
  (setq AA2 (/ (* HAL HAL) 2.0))
  (setq AA (sqrt AA2))
  (setq QTR (/ PWIDTH 4.0))
  (setq Q2 (/ (* qtr qtr) 2.0))
  (setq Q (sqrt Q2))
  (setq NUM (/ L PWIDTH))
  (setq NUM (fix NUM))
  (setq PW (* NUM PWIDTH))
  (setq DIFF (- L pw))
  (if (>= DIFF HALF)                ; if
    (setq HDIST (- DIFF HALF))     ; then
    (setq HDIST DIFF)              ; else
  )
  ; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
  ; draw odd-ball size horizontal panel
  (if (> HDIST 0)
    (progn
      (setq H1 (polar SP (+ angr (dtr 90)) HAL))
      (setq H2 (polar H1 ANGR HDIST))
      (setq H3 (polar H2 (- ANGR (dtr 90)) PTHICK))
      (setq H4 (polar H3 ANGL HDIST))
      (setq SP (polar SP ANGR (+ HDIST AA)))
      (command "pline" H1 H2 H3 H4 "c")
    ) ; end of progn
  )   ; end of if
  ; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
  ; draw diagonal half-size panel
  (if (>= DIFF HALF)
    (progn
      (setq PT1 (polar SP (+ ANGR (dtr 135)) HAL))
      (setq PT2 (polar PT1 (+ ANGR (dtr 45)) HALF))
      (setq PT4 (polar PT2 (- ANGR (dtr 45)) PTHICK))
      (setq PT3 (polar PT1 (- ANGR (dtr 45)) PTHICK))
      (command "pline" PT1 pT2 PT4 PT3 "c")
      (setq SP (polar SP ANGR (+ A AA)))
    ) ; end of progn
  )   ; end of if
  ; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
  ; draw diagonal full-size panels
  (setq LOOP num)
  (setq PT1 (polar SP (+ ANGR (dtr 90)) (- A AA)))
  (setq PT2 (polar PT1 (- ANGR (dtr 45)) HALF))
  (repeat LOOP
    (if (>= LOOP 1)
      (progn 
        (setq PT2 (polar PT1 (- angr (dtr 45)) PWIDTH))
        (setq PT3 (polar PT1 (+ angr (dtr 45)) PTHICK))
        (setq PT4 (polar PT2 (+ angr (dtr 45)) PTHICK))
        (command "pline" PT1 PT2 PT4 PT3 "c")
        (setq LOOP (- LOOP 1))
      )
    )
    (if (>= LOOP 1)
      (progn 
        (setq PT5 (polar PT4 (+ ANGR (dtr 45)) PWIDTH))
        (setq PT6 (polar PT4 (- ANGR (dtr 45)) PTHICK))
        (setq PT7 (polar PT6 (+ ANGR (dtr 45)) PWIDTH))
        (command "pline" PT4 PT5 PT7 PT6 PT4 "")
        (setq LOOP (- LOOP 1))
      )
    )
    (setq PT1 PT7)
  )
  (END)
  (princ)
)   ;end of routine
; ***********************************************************************
( defun dtr (D) 
  (/ (* D pi) 180.0)
)
; ***********************************************************************
;                        ERROR FUNCTION 
;****************************************************************
; Function resets beginning values if an error occurs or (ctrl-C).
(defun *error* (MSG)
  (if (/= MSG "Function cancelled")
    (princ (strcat "\nAutoLISP Error:  " MSG))
    (terpri)
  )
  (END)
  (princ)
)  ; END OF FUNCTION
;****************************************************************
;                        START FUNCTION 
;****************************************************************
(defun START ()
  (setq OLDERR *error*)
  (setq S_CMD (getvar "cmdecho"))
  (setvar "cmdecho" 0)
  (setq S_OSM (getvar "osmode"))
  (setvar "osmode" 0)   ; NONE
  (setq S_BLIP (getvar "blipmode"))
  (setvar "blipmode" 0)
  (setq S_ORTH (getvar "orthomode"))
  (setvar "orthomode" 0)             ;Ortho off
  (graphscr)
  (command "pline" (list 0 0) "w" "0" "" (list 1 1) "" ) (entdel (entlast))
  (setq cl (getvar "clayer"))
)   ;end of START function
;****************************************************************
;                         END FUNCTION 
;****************************************************************
(defun END ()
  (setvar "blipmode" S_BLIP)
  (setvar "orthomode" S_ORTH)
  (setvar "osmode" S_OSM)
  (command "layer" "s" cl "")
  (setq *error* OLDERR)
  (setvar "cmdecho" S_CMD)
  (princ)
)   ; end of END function
(princ); end zigzag.lsp
